==> ideaIC-171.2014.21-sources.jar: com/android/tools/idea/actions/MeetAndroidStudioHelpAction.java <==
/*
 * Copyright (C) 2016 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.actions;

import com.intellij.icons.AllIcons;
import com.intellij.ide.BrowserUtil;
import com.intellij.openapi.actionSystem.ActionPlaces;
import com.intellij.openapi.actionSystem.AnAction;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.actionSystem.Presentation;

public class MeetAndroidStudioHelpAction extends AnAction {

  public MeetAndroidStudioHelpAction() {
    super("Android Studio Help", "Help", AllIcons.Actions.Help);
  }

  @Override
  public void update(AnActionEvent e) {
    if (e.getPlace().equals(ActionPlaces.MAIN_MENU)) {
      // Remove the toolbar icon from the menu to keep all the menu items left aligned:
      Presentation presentation = e.getPresentation();
      presentation.setIcon(null);
    }
  }

  @Override
  public void actionPerformed(AnActionEvent e) {
    BrowserUtil.browse("http://developer.android.com/r/studio-ui/menu-help.html");
  }
}

==> ideaIC-2018.3.3-sources.jar: com/android/tools/idea/actions/MeetAndroidStudioHelpAction.java <==
/*
 * Copyright (C) 2016 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.actions;

import com.intellij.icons.AllIcons;
import com.intellij.ide.BrowserUtil;
import com.intellij.openapi.actionSystem.ActionPlaces;
import com.intellij.openapi.actionSystem.AnAction;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.actionSystem.Presentation;
import org.jetbrains.annotations.NotNull;

public class MeetAndroidStudioHelpAction extends AnAction {

  public MeetAndroidStudioHelpAction() {
    super("Android Studio Help", "Help", AllIcons.Actions.Help);
  }

  @Override
  public void update(@NotNull AnActionEvent e) {
    if (e.getPlace().equals(ActionPlaces.MAIN_MENU)) {
      // Remove the toolbar icon from the menu to keep all the menu items left aligned:
      Presentation presentation = e.getPresentation();
      presentation.setIcon(null);
    }
  }

  @Override
  public void actionPerformed(@NotNull AnActionEvent e) {
    BrowserUtil.browse("http://developer.android.com/r/studio-ui/menu-help.html");
  }
}
